@@ -16,9 +16,8 @@ Module, to identify which block character belongs to, what block name is
 and some more convenience functions.
 """
 from collections import namedtuple
-from .unicodeblocks import Block, Blocks, blocks
+from unicodeblocks._unicodeblocks import Block, blocks, blockof
 
-
-version_info = namedtuple('version_info', 'major minor')(0, 1)
+version_info = namedtuple('version_info', 'major minor')(0, 2)
 version = "{0.major}.{0.minor}".format(version_info)
-
+unidata_version = '6.2.0'
